@@ -7,7 +7,7 @@ import sys
 from . import common
 from .log import enable_colourful_output
 
-__version__ = '1.0'
+__version__ = '1.1'
 
 log = logging.getLogger(__name__)
 
@@ -25,7 +25,7 @@ def add_shared_install_options(parser):
 def main(argv=None):
     ap = argparse.ArgumentParser()
     ap.add_argument('-f', '--ini-file', type=pathlib.Path, default='pyproject.toml')
-    ap.add_argument('--version', action='version', version='Flit '+__version__)
+    ap.add_argument('-V', '--version', action='version', version='Flit '+__version__)
     ap.add_argument('--repository',
         help="Name of the repository to upload to (must be in ~/.pypirc)"
     )
@@ -60,7 +60,12 @@ def main(argv=None):
     )
     add_shared_install_options(parser_install)
     parser_install.add_argument('--deps', choices=['all', 'production', 'develop', 'none'], default='all',
-        help="Which set of dependencies to install")
+        help="Which set of dependencies to install. If --deps=develop, the extras dev, doc, and test are installed"
+    )
+    parser_install.add_argument('--extras', default=(), type=lambda l: l.split(',') if l else (),
+        help="Install the dependencies of these (comma separated) extras additionally to the ones implied by --deps. "
+             "--extras=all can be useful in combination with --deps=production, --deps=none precludes using --extras"
+    )
 
     parser_installfrom = subparsers.add_parser('installfrom',
        help="Download and install a package using flit from source"
@@ -98,7 +103,10 @@ def main(argv=None):
 
     if args.subcmd == 'build':
         from .build import main
-        main(args.ini_file, formats=set(args.format or []))
+        try:
+            main(args.ini_file, formats=set(args.format or []))
+        except(common.NoDocstringError) as e:
+            sys.exit(e.args[0])
     elif args.subcmd == 'publish':
         from .upload import main
         main(args.ini_file, args.repository, formats=set(args.format or []))
@@ -107,7 +115,8 @@ def main(argv=None):
         from .install import Installer
         try:
             Installer(args.ini_file, user=args.user, python=args.python,
-                      symlink=args.symlink, deps=args.deps, pth=args.pth_file).install()
+                      symlink=args.symlink, deps=args.deps, extras=args.extras,
+                      pth=args.pth_file).install()
         except (common.NoDocstringError, common.NoVersionError) as e:
             sys.exit(e.args[0])
     elif args.subcmd == 'installfrom':
