@@ -84,17 +84,24 @@ class RootInstallError(Exception):
         return ("Installing packages as root is not recommended. "
             "To allow this, set FLIT_ROOT_INSTALL=1 and try again.")
 
+class DependencyError(Exception):
+    def __str__(self):
+        return 'To install dependencies for extras, you cannot set deps=none.'
+
 class Installer(object):
     def __init__(self, ini_path, user=None, python=sys.executable,
-                 symlink=False, deps='all', pth=False):
+                 symlink=False, deps='all', extras=(), pth=False):
         self.ini_path = ini_path
         self.python = python
         self.symlink = symlink
         self.pth = pth
         self.deps = deps
+        self.extras = extras
         if deps != 'none' and os.environ.get('FLIT_NO_NETWORK', ''):
             self.deps = 'none'
             log.warning('Not installing dependencies, because FLIT_NO_NETWORK is set')
+        if deps == 'none' and extras:
+            raise DependencyError()
 
         self.ini_info = inifile.read_pkg_ini(ini_path)
         self.module = common.Module(self.ini_info['module'], ini_path.parent)
@@ -184,6 +191,20 @@ class Installer(object):
             for f in files:
                 self.installed_files.append(os.path.join(dirpath, f))
 
+    @property
+    def extra_reqs(self):
+        return self.ini_info['metadata'].get('requires_extra', {})
+
+    def _extras_to_install(self):
+        extras_to_install = set(self.extras)
+        if self.deps == 'all' or 'all' in extras_to_install:
+            extras_to_install |= set(self.extra_reqs.keys())
+            # We don’t remove 'all' from the set because there might be an extra called “all”.
+        elif self.deps == 'develop':
+            extras_to_install |= {'dev', 'doc', 'test'}
+        log.info("Extras to install for deps %r: %s", self.deps, extras_to_install)
+        return extras_to_install
+
     def install_requirements(self):
         """Install requirements of a package with pip.
 
@@ -196,8 +217,9 @@ class Installer(object):
             return
         if self.deps in ('all', 'production'):
             requirements.extend(self.ini_info['metadata'].get('requires_dist', []))
-        if self.deps in ('all', 'develop'):
-            requirements.extend(self.ini_info['metadata'].get('dev_requires', []))
+
+        for extra in self._extras_to_install():
+            requirements.extend(self.extra_reqs.get(extra, []))
 
         # there aren't any requirements, so return
         if len(requirements) == 0:
@@ -311,8 +333,11 @@ class Installer(object):
 
             renamed_whl = os.path.join(td, wb.wheel_filename)
             os.rename(temp_whl, renamed_whl)
+            extras = self._extras_to_install()
+            whl_with_extras = '{}[{}]'.format(renamed_whl, ','.join(extras)) \
+                if extras else renamed_whl
 
-            cmd = [self.python, '-m', 'pip', 'install', renamed_whl]
+            cmd = [self.python, '-m', 'pip', 'install', whl_with_extras]
             if self.user:
                 cmd.append('--user')
             if self.deps == 'none':
